@@ -26,7 +26,7 @@
 
 AuthorizedAppModel::AuthorizedAppModel(KWallet::Wallet *wallet):
     QStandardItemModel(),
-    _cfg(KSharedConfig::openConfig(QLatin1String("kwalletrc"), KConfig::NoGlobals)),
+    _cfg(KSharedConfig::openConfig(QStringLiteral("kwalletrc"), KConfig::NoGlobals)),
     _wallet(wallet)
 {
     // TODO: handle "Auto Deny" applications
@@ -35,13 +35,13 @@ AuthorizedAppModel::AuthorizedAppModel(KWallet::Wallet *wallet):
     KConfigGroup aa(_cfg, "Auto Allow");
     QString walletName = _wallet->walletName();
     const QStringList keys = aa.entryMap().keys();
-    Q_FOREACH(QString cfgWalletName, keys) {
+    for (const QString &cfgWalletName : keys) {
         if (cfgWalletName == walletName) {
             const QStringList apps = aa.readEntry(cfgWalletName, QStringList());
             int row = 0;
-            Q_FOREACH(QString appName, apps) {
+            for (const QString &appName : apps) {
                 setItem(row, 0, new QStandardItem(appName));
-                setItem(row, 1, new QStandardItem("dummy")); // this item will be hidden by the disconnect button, see below setIndexWidget call
+                setItem(row, 1, new QStandardItem(QStringLiteral("dummy"))); // this item will be hidden by the disconnect button, see below setIndexWidget call
                 _authorizedAppsIndexMap.insert(appName, QPersistentModelIndex(index(row, 0)));
                 row++;
             }
@@ -49,7 +49,7 @@ AuthorizedAppModel::AuthorizedAppModel(KWallet::Wallet *wallet):
     }
 }
 
-void AuthorizedAppModel::removeApp(QString appName)
+void AuthorizedAppModel::removeApp(const QString &appName)
 {
     if (_authorizedAppsIndexMap.contains(appName)) {
         QPersistentModelIndex idx = _authorizedAppsIndexMap[appName];
@@ -61,12 +61,13 @@ void AuthorizedAppModel::removeApp(QString appName)
     } else {
         qDebug() << "Attempting to remove unknown application " << appName;
     }
-    QTimer::singleShot(0, this, SLOT(saveConfig()));
+    QTimer::singleShot(0, this, &AuthorizedAppModel::saveConfig);
 }
 
 void AuthorizedAppModel::saveConfig()
 {
     QStringList appList;
+    appList.reserve(rowCount());
     for (int r = 0; r < rowCount(); r++) {
         appList << item(r)->text();
     }
